******************************************************
** FILE NAME	: ClkBiasBrdTst50.asm
** PROJECT	: MONSOON
** TITLE	: TEST ROUTINE FOR STAGE 5 OF CLOCK AND BIAS FUNCTIONAL TESTS
** VERSION	: 000
** DATE		: 02/22/2004
** AUTHOR	: PETER MOORE
** HISTORY	: 02/22/2004 PCM ORIGINAL VERSION.
**
** DESCRIPTION : Toggles the slow bias DACs between 10% and 90% of their full scale value
**
** RESOURCES :
** CMD REG
** BIT
** 
** 0 => ALWAYS ONE. FORMS THE BRANCH UNCONDITIONAL INSTRUCTION.
** 1 => SYNCHRONIZATION BIT. SET BY EXTERNAL SIGNAL IN SLAVE MODE ELSE INTERNAL EFR REGISTER BIT. 
** 2 => INTEGRATION TIMER FLAG. INDICATES THAT INTEGRATION TIME HAS EXPIRED.
** 3 => SET BY THE START EXPOSURE ROUTINE (set by Start Exposure vector)
** 4 => NOT USED
** 5 => NOT USED
** 6 => NOT USED
** 7 => NOT USED
** 8 => NOT USED
** 9 => NOT USED
** (set by direct write to Command Register at MCB addr 0x102)
** 12 => NOT USED (command "c w 1 0x102 1")
** 13 => NOT USED (command "c w 1 0x102 2")
** 14 => NOT USED (command "c w 1 0x102 4")
** 15 => NOT USED (command "c w 1 0x102 8")
**
** LOOP CNTR
** REGS
**  0  => BIAS CHANNEL COUNTER = 36
**  1  => DELAY COUNTER FOR DELAY BETWEEN SETTING EACH BIAS CHANNEL (UNITS OF MILLISECONDS) = 10
**  2  => NOT USED.
**  3  => NOT USED.
**  4  => NOT USED.
**  5  => NOT USED.
**  6  => NOT USED.
**  7  => NOT USED.
**  8  => NOT USED.
**  9  => NOT USED.
** 10  => NOT USED.
** 11  => NOT USED.
** 12  => NOT USED.
** 13  => NOT USED.
** 14  => NOT USED.
** 15  => NOT USED.
********************************************************
DEF #RESET	    0			* Mode register constant for board reset operation
DEF #READ 	    1			* Mode register constant for read operation
DEF #WRITE16	    2			* Mode register constant for 16 bit write operation
DEF #WRITE32	    3			* Mode register constant for 32 bit write operation
DEF #BIASLOOP	    0			* Loop register 0 used as Bias channel counter
DEF #DELAYLOOP	    1			* Loop register 1 used as delay counter
DEF #CLKBRD	    2			* Address of the clock board
DEF #DESLCT	    0			* Delselects the write
DEF #DELAY	    1			* Unit delay time
PAT #BIAS00_10 x0100001A
PAT #BIAS01_10 x0101001A
PAT #BIAS02_10 x0102001A
PAT #BIAS03_10 x0103001A
PAT #BIAS04_10 x0104001A
PAT #BIAS05_10 x0105001A
PAT #BIAS06_10 x0106001A
PAT #BIAS07_10 x0107001A
PAT #BIAS08_10 x0108001A
PAT #BIAS09_10 x0109001A
PAT #BIAS10_10 x010a001A
PAT #BIAS11_10 x010b001A
PAT #BIAS12_10 x010c001A
PAT #BIAS13_10 x010d001A
PAT #BIAS14_10 x010e001A
PAT #BIAS15_10 x010f001A
PAT #BIAS16_10 x0110001A
PAT #BIAS17_10 x0111001A
PAT #BIAS18_10 x0112001A
PAT #BIAS19_10 x0113001A
PAT #BIAS20_10 x0114001A
PAT #BIAS21_10 x0115001A
PAT #BIAS22_10 x0116001A
PAT #BIAS23_10 x0117001A
PAT #BIAS24_10 x0118001A
PAT #BIAS25_10 x0119001A
PAT #BIAS26_10 x011a001A
PAT #BIAS27_10 x011b001A
PAT #BIAS28_10 x011c001A
PAT #BIAS29_10 x011d001A
PAT #BIAS30_10 x011e001A
PAT #BIAS31_10 x011f001A
PAT #BIAS32_10 x0120001A
PAT #BIAS33_10 x0121001A
PAT #BIAS34_10 x0122001A
PAT #BIAS35_10 x0123001A

PAT #BIAS00_90 x010000E6
PAT #BIAS01_90 x010100E6
PAT #BIAS02_90 x010200E6
PAT #BIAS03_90 x010300E6
PAT #BIAS04_90 x010400E6
PAT #BIAS05_90 x010500E6
PAT #BIAS06_90 x010600E6
PAT #BIAS07_90 x010700E6
PAT #BIAS08_90 x010800E6
PAT #BIAS09_90 x010900E6
PAT #BIAS10_90 x010a00E6
PAT #BIAS11_90 x010b00E6
PAT #BIAS12_90 x010c00E6
PAT #BIAS13_90 x010d00E6
PAT #BIAS14_90 x010e00E6
PAT #BIAS15_90 x010f00E6
PAT #BIAS16_90 x011000E6
PAT #BIAS17_90 x011100E6
PAT #BIAS18_90 x011200E6
PAT #BIAS19_90 x011300E6
PAT #BIAS20_90 x011400E6
PAT #BIAS21_90 x011500E6
PAT #BIAS22_90 x011600E6
PAT #BIAS23_90 x011700E6
PAT #BIAS24_90 x011800E6
PAT #BIAS25_90 x011900E6
PAT #BIAS26_90 x011a00E6
PAT #BIAS27_90 x011b00E6
PAT #BIAS28_90 x011c00E6
PAT #BIAS29_90 x011d00E6
PAT #BIAS30_90 x011e00E6
PAT #BIAS31_90 x011f00E6
PAT #BIAS32_90 x012000E6
PAT #BIAS33_90 x012100E6
PAT #BIAS34_90 x012200E6
PAT #BIAS35_90 x012300E6

**
*** Program segment starts here
**
#START	LMR #WRITE16		* Set 16 bit write mode
	LPP #BIAS00_10		* point to the first bias channel 10% value
	CAL #DOLOOP		* call the loop sub
	LPP #BIAS00_90		* point to the first bias channel 90% value
	CAL #DOLOOP		* go do it again
	JMP #START		* Loop indefinately

#DOLOOP	LRB #BIASLOOP		* Start counting through the bias channels
	LSR #CLKBRD
	LSR #DESLCT		* write out the value
	IPP			* point to the next bias channel
	LRB #DELAYLOOP
	DMS #DELAY		* Loop on the required delay
	LPE			* end of delay loop
	LPE			* end of bias channel loop
	RET			* Return for more punishment
**
*** End of program segment
**
