******************************************************
** FILE NAME	: ClkBiasBrdTst60_slot2.asm
** PROJECT	: MONSOON
** TITLE	: TEST ROUTINE FOR STAGE 6 OF CLOCK AND BIAS FUNCTIONAL TESTS
** VERSION	: 001
** DATE		: 02/22/2004
** AUTHOR	: PETER MOORE
** HISTORY	: 02/22/2004 PCM ORIGINAL VERSION.
**              : 09/16/2004 PCM CHANGED FOR VERSION 4.0 FIRMWARE ON REV 1 HARDWARE
**		: 12/22/2004 PJS added slot2 testing for 6 slot backplane
**
** DESCRIPTION  : Toggles the clocks between 10% and 90% of their full scale value
**              : to assess the clock edge rise time.
** RESOURCES    :
** CMD REG
** BIT
** 
** 0 => ALWAYS ONE. FORMS THE BRANCH UNCONDITIONAL INSTRUCTION.
** 1 => SYNCHRONIZATION BIT. SET BY EXTERNAL SIGNAL IN SLAVE MODE ELSE INTERNAL EFR REGISTER BIT. 
** 2 => INTEGRATION TIMER FLAG. INDICATES THAT INTEGRATION TIME HAS EXPIRED.
** 3 => SET BY THE START EXPOSURE ROUTINE (set by Start Exposure vector)
** 4 => NOT USED
** 5 => NOT USED
** 6 => NOT USED
** 7 => NOT USED
** 8 => NOT USED
** 9 => NOT USED
** (set by direct write to Command Register at MCB addr 0x102)
** 12 => NOT USED (command "c w 1 0x102 1")
** 13 => NOT USED (command "c w 1 0x102 2")
** 14 => NOT USED (command "c w 1 0x102 4")
** 15 => NOT USED (command "c w 1 0x102 8")
**
** LOOP CNTR
** REGS
**  0  => NUMBER OF CLOCK CHANNELS = 32.
**  1  => DELAY COUNTER FOR DELAY BETWEEN CLOCK TRANSITIONS (UNITS OF MICROSECONDS) = 10
**  2  => DELAY COUNTER FOR DELAY BETWEEN CLOCK DAC LOADS (UNITS OF MILLISECONDS) = 10
**  3  => NOT USED.
**  4  => NOT USED.
**  5  => NOT USED.
**  6  => NOT USED.
**  7  => NOT USED.
**  8  => NOT USED.
**  9  => NOT USED.
** 10  => NOT USED.
** 11  => NOT USED.
** 12  => NOT USED.
** 13  => NOT USED.
** 14  => NOT USED.
** 15  => NOT USED.
********************************************************
DEF #RESET	    0			* Mode register constant for board reset operation
DEF #READ 	    1			* Mode register constant for read operation
DEF #WRITE16	    2			* Mode register constant for 16 bit write operation
DEF #WRITE32	    3			* Mode register constant for 32 bit write operation
DEF #CLKLOOP	    0			* Loop register 0 used as Bias channel counter
DEF #DELAYLOOP	    1			* Loop register 1 used as delay counter
DEF #LOADLOOP	    2			* Loop register 1 used as delay counter
DEF #CLKBRD	    2			* Address of the clock board
DEF #DESLCT	    0			* Delselects the write
DEF #DELAY	    1			* Unit delay time
DEF #CLKPORT	    0			* On board address of clock register

PAT #CLK00_LOW x0124001A
PAT #CLK01_LOW x0125001A
PAT #CLK02_LOW x0126001A
PAT #CLK03_LOW x0127001A
PAT #CLK04_LOW x0128001A
PAT #CLK05_LOW x0129001A
PAT #CLK06_LOW x012A001A
PAT #CLK07_LOW x012B001A
PAT #CLK08_LOW x012C001A
PAT #CLK09_LOW x012D001A
PAT #CLK10_LOW x012E001A
PAT #CLK11_LOW x012F001A
PAT #CLK12_LOW x0130001A
PAT #CLK13_LOW x0131001A
PAT #CLK14_LOW x0132001A
PAT #CLK15_LOW x0133001A
PAT #CLK16_LOW x0134001A
PAT #CLK17_LOW x0135001A
PAT #CLK18_LOW x0136001A
PAT #CLK19_LOW x0137001A
PAT #CLK20_LOW x0138001A
PAT #CLK21_LOW x0139001A
PAT #CLK22_LOW x013A001A
PAT #CLK23_LOW x013B001A
PAT #CLK24_LOW x013C001A
PAT #CLK25_LOW x013D001A
PAT #CLK26_LOW x013E001A
PAT #CLK27_LOW x013F001A
PAT #CLK28_LOW x0140001A
PAT #CLK29_LOW x0141001A
PAT #CLK30_LOW x0142001A
PAT #CLK31_LOW x0143001A

PAT #CLK00_HIGH x014400E6
PAT #CLK01_HIGH x014500E6
PAT #CLK02_HIGH x014600E6
PAT #CLK03_HIGH x014700E6
PAT #CLK04_HIGH x014800E6
PAT #CLK05_HIGH x014900E6
PAT #CLK06_HIGH x014A00E6
PAT #CLK07_HIGH x014B00E6
PAT #CLK08_HIGH x014C00E6
PAT #CLK09_HIGH x014D00E6
PAT #CLK10_HIGH x014E00E6
PAT #CLK11_HIGH x014F00E6
PAT #CLK12_HIGH x015000E6
PAT #CLK13_HIGH x015100E6
PAT #CLK14_HIGH x015200E6
PAT #CLK15_HIGH x015300E6
PAT #CLK16_HIGH x015400E6
PAT #CLK17_HIGH x015500E6
PAT #CLK18_HIGH x015600E6
PAT #CLK19_HIGH x015700E6
PAT #CLK20_HIGH x015800E6
PAT #CLK21_HIGH x015900E6
PAT #CLK22_HIGH x015A00E6
PAT #CLK23_HIGH x015B00E6
PAT #CLK24_HIGH x015C00E6
PAT #CLK25_HIGH x015D00E6
PAT #CLK26_HIGH x015E00E6
PAT #CLK27_HIGH x015F00E6
PAT #CLK28_HIGH x016000E6
PAT #CLK29_HIGH x016100E6
PAT #CLK30_HIGH x016200E6
PAT #CLK31_HIGH x016300E6
PAT #CLOCKS_LOW x00000000
PAT #CLOCKS_HI  xFFFFFFFF

**
*** Program segment starts here
**
#START	LMR #WRITE16		* Set 16 bit write mode
	LPP #CLK00_LOW		* point to the first clock channel 10% value
	CAL #SETUP		* call the setup loop
	LPP #CLK00_HIGH		* point to the first bias channel 90% value
	CAL #SETUP		* go do it again for clock high values
	LMR #WRITE32		* setup for clock port writes
	LDA #CLKPORT		* point to the on board address
#TGGL	LPP #CLOCKS_LOW
	LSR #CLKBRD
	LSR #DESLCT		* write out low value
	LRB #DELAYLOOP
	DUS #DELAY
	LPE			* end of delay loop for low settle time
	LPP #CLOCKS_HI
	LSR #CLKBRD
	LSR #DESLCT		* write out high value
	LRB #DELAYLOOP
	DUS #DELAY
	LPE			* end of delay loop for high settle time
	JMP #TGGL		* loop endlessly

#SETUP	LRB #CLKLOOP		* Start counting through the clock channels
	LSR #CLKBRD
	LSR #DESLCT		* write out the value
	IPP			* point to the next bias channel
	LRB #LOADLOOP
	DMS #DELAY		* Loop on the required delay
	LPE			* end of delay loop
	LPE			* end of bias channel loop
	RET			* Return for more punishment
**
*** End of program segment
**
