******************************************************
** FILE NAME	: ClkBiasBrdTst70_NoT.asm
** PROJECT	: MONSOON
** TITLE	: TEST ROUTINE FOR STAGE 7 OF CLOCK AND BIAS FUNCTIONAL TESTS
** VERSION	: 000
** DATE		: 02/22/2004
** AUTHOR	: PETER MOORE
** HISTORY	: 02/22/2004 PCM ORIGINAL VERSION.
**              : 03/18/2005 PJS & JPG changed CLKPORTTST2 from XFFFFFFFF to X00000000.
**
** DESCRIPTION  : Toggles the fast biases between 10% and 90% of their full scale value
**              : to assess the rise time.
** RESOURCES    :
** CMD REG
** BIT
** 
** 0 => ALWAYS ONE. FORMS THE BRANCH UNCONDITIONAL INSTRUCTION.
** 1 => SYNCHRONIZATION BIT. SET BY EXTERNAL SIGNAL IN SLAVE MODE ELSE INTERNAL EFR REGISTER BIT. 
** 2 => INTEGRATION TIMER FLAG. INDICATES THAT INTEGRATION TIME HAS EXPIRED.
** 3 => SET BY THE START EXPOSURE ROUTINE (set by Start Exposure vector)
** 4 => NOT USED
** 5 => NOT USED
** 6 => NOT USED
** 7 => NOT USED
** 8 => NOT USED
** 9 => NOT USED
** (set by direct write to Command Register at MCB addr 0x102)
** 12 => NOT USED (command "c w 1 0x102 1")
** 13 => NOT USED (command "c w 1 0x102 2")
** 14 => NOT USED (command "c w 1 0x102 4")
** 15 => NOT USED (command "c w 1 0x102 8")
**
** LOOP CNTR
** REGS
**  0  => DELAY COUNTER FOR DELAY BETWEEN CLOCK TRANSITIONS (UNITS OF MICROSECONDS) = 10
**  1  => NOT USED.
**  2  => NOT USED.
**  3  => NOT USED.
**  4  => NOT USED.
**  5  => NOT USED.
**  6  => NOT USED.
**  7  => NOT USED.
**  8  => NOT USED.
**  9  => NOT USED.
** 10  => NOT USED.
** 11  => NOT USED.
** 12  => NOT USED.
** 13  => NOT USED.
** 14  => NOT USED.
** 15  => NOT USED.
********************************************************
DEF #RESET	    0			* Mode register constant for board reset operation
DEF #READ 	    1			* Mode register constant for read operation
DEF #WRITE16	    2			* Mode register constant for 16 bit write operation
DEF #WRITE32	    3			* Mode register constant for 32 bit write operation
DEF #DELAYLOOP	    0			* Loop register 1 used as delay counter
DEF #CLKBRD	    128			* Address of the clock board
DEF #DESLCT	    0			* Delselects the write
DEF #DELAY	    1			* Unit delay time
DEF #FBIASPORT0	    1			* On board address of fast bias channels 0,1,2,3
DEF #FBIASPORT1	    2			* On board address of fast bias channels 4,5,6,7
DEF #CLKPORT        0

PAT #FASTBIASLOW x00000000
PAT #FASTBIASHI  x00000001
PAT #CLKPORTTST1  x00000000
PAT #CLKPORTTST2  x00000000
**
*** Program segment starts here
**
#START	LMR #WRITE32		* setup for 32 bit writes
#CONT	LDA #FBIASPORT0		* point to the on board address
	LPP #FASTBIASLOW
	LSR #CLKBRD
	LSR #DESLCT		* write out low value to channels 0,1,2,3
	DUS 120
**	LSR #CLKBRD
**	LSR #DESLCT		* twice for bug in firmware
	LDA #FBIASPORT1		* point to the on board address for second bank
	LSR #CLKBRD
	LSR #DESLCT		* write out low value to channels 4,5,6,7
	DUS 120
        LDA #CLKPORT
        LPP #CLKPORTTST1
	LSR #CLKBRD
	LSR #DESLCT		* Write debug info to clock port
	LRB #DELAYLOOP
	DUS #DELAY
	LPE			* end of delay loop for low settle time
	LDA #FBIASPORT0		* point to the on board address
	LPP #FASTBIASHI
	LSR #CLKBRD
	LSR #DESLCT		* write out high value to channels 0,1,2,3
	DUS 120
**	LSR #CLKBRD
**	LSR #DESLCT		* twice for bug in firmware
	LDA #FBIASPORT1		* point to the on board address for second bank
	LSR #CLKBRD
	LSR #DESLCT		* write out high value to channels 4,5,6,7
	DUS 120
        LDA #CLKPORT
        LPP #CLKPORTTST2
	LSR #CLKBRD
	LSR #DESLCT		* twice for bug in firmware
	LRB #DELAYLOOP
	DUS #DELAY
	LPE			* end of delay loop for high settle time
	JMP #CONT		* loop endlessly
**
*** End of program segment
**
