******************************************************
** FILE NAME	: ClkBiasBrdTst90.asm
** PROJECT	: MONSOON
** TITLE	: TEST ROUTINE FOR STAGE 9 OF CLOCK AND BIAS FUNCTIONAL TESTS
** VERSION	: 001
** DATE		: 09/24/2004
** AUTHOR	: PETER MOORE
** HISTORY	: 02/22/2004 PCM ORIGINAL VERSION.
**              : 09/24/2004 PCM MODIFIED TO WORK WITH FIRMWARE VERSION 4.00 AND HARDWARE REV 1
**              :
**
** DESCRIPTION  : Toggles the clocks between 10% and 90% of their full scale value
**              : while scanning the clock mux accross the channels.
** RESOURCES    :
** CMD REG
** BIT
** 
** 0 => ALWAYS ONE. FORMS THE BRANCH UNCONDITIONAL INSTRUCTION.
** 1 => SYNCHRONIZATION BIT. SET BY EXTERNAL SIGNAL IN SLAVE MODE ELSE INTERNAL EFR REGISTER BIT. 
** 2 => INTEGRATION TIMER FLAG. INDICATES THAT INTEGRATION TIME HAS EXPIRED.
** 3 => SET BY THE START EXPOSURE ROUTINE (set by Start Exposure vector)
** 4 => NOT USED
** 5 => NOT USED
** 6 => NOT USED
** 7 => NOT USED
** 8 => NOT USED
** 9 => NOT USED
** 12 => NOT USED (command "c w 1 0x102 1")
** 13 => NOT USED (command "c w 1 0x102 2")
** 14 => NOT USED (command "c w 1 0x102 4")
** 15 => NOT USED (command "c w 1 0x102 8")
**
** LOOP CNTR
** REGS
**  0  => NUMBER OF CLOCK CHANNELS * 2 = 64.
**  1  => DELAY COUNTER FOR DELAY BETWEEN CLOCK TRANSITIONS (UNITS OF MICROSECONDS) = 1
**  2  => DELAY COUNTER FOR DELAY BETWEEN CLOCK DAC LOADS (UNITS OF MILLISECONDS) = 10
**  3  => HOLD OFF DELAY USED TO STABILIZE SCOPE DISPLAY.
**  4  => NOT USED.
**  5  => NOT USED.
**  6  => NOT USED.
**  7  => NOT USED.
**  8  => NOT USED.
**  9  => NOT USED.
** 10  => NOT USED.
** 11  => NOT USED.
** 12  => NOT USED.
** 13  => NOT USED.
** 14  => NOT USED.
** 15  => NOT USED.
********************************************************
*
** lOCAL DEFINITIONS
*
DEF #RESET	    0			* Mode register constant for board reset operation
DEF #READ 	    1			* Mode register constant for read operation
DEF #WRITE16	    2			* Mode register constant for 16 bit write operation
DEF #WRITE32	    3			* Mode register constant for 32 bit write operation
DEF #CLKLOOP	    0			* Loop register 0 used as Bias channel counter
DEF #DELAYLOOP	    1			* Loop register 1 used as delay counter
DEF #LOADLOOP	    2			* Loop register 2 used as delay counter
DEF #HOLDOFF	    3			* Loop register 3 used to holdoff delay value
DEF #CLKBRD	    128			* Address of the clock board
DEF #DESLCT	    0			* Delselects the write
DEF #DELAY	    1			* Unit delay time in us.
DEF #HOLDDELAY      3			* Hold off delay unit in us.
DEF #CLKPORT	    0			* On board address of clock register
*
** Clock DAC settings for 10% AND 90%
*
PAT #CLK00_HIGH x01240084
PAT #CLK00_LOW  x0144007C
PAT #CLK01_HIGH x01250088
PAT #CLK01_LOW  x01450078
PAT #CLK02_HIGH x0126008C
PAT #CLK02_LOW  x01460074
PAT #CLK03_HIGH x01270090
PAT #CLK03_LOW  x01470070
PAT #CLK04_HIGH x01280094
PAT #CLK04_LOW  x0148006C
PAT #CLK05_HIGH x01290098
PAT #CLK05_LOW  x01490068
PAT #CLK06_HIGH x012A009C
PAT #CLK06_LOW  x014A0064
PAT #CLK07_HIGH x012B00A0
PAT #CLK07_LOW  x014B0060
PAT #CLK08_HIGH x012C00A4
PAT #CLK08_LOW  x014C005C
PAT #CLK09_HIGH x012D00A8
PAT #CLK09_LOW  x014D0058
PAT #CLK10_HIGH x012E00AC
PAT #CLK10_LOW  x014E0054
PAT #CLK11_HIGH x012F00B0
PAT #CLK11_LOW  x014F0050
PAT #CLK12_HIGH x013000B4
PAT #CLK12_LOW  x0150004C
PAT #CLK13_HIGH x013100B8
PAT #CLK13_LOW  x01510048
PAT #CLK14_HIGH x013200BC
PAT #CLK14_LOW  x01520044
PAT #CLK15_HIGH x013300C0
PAT #CLK15_LOW  x01530040
PAT #CLK16_HIGH x013400C4
PAT #CLK16_LOW  x0154003C
PAT #CLK17_HIGH x013500C8
PAT #CLK17_LOW  x01550038
PAT #CLK18_HIGH x013600CC
PAT #CLK18_LOW  x01560034
PAT #CLK19_HIGH x013700D0
PAT #CLK19_LOW  x01570030
PAT #CLK20_HIGH x013800D4
PAT #CLK20_LOW  x0158002C
PAT #CLK21_HIGH x013900D8
PAT #CLK21_LOW  x01590028
PAT #CLK22_HIGH x013A00DC
PAT #CLK22_LOW  x015A0024
PAT #CLK23_HIGH x013B00E0
PAT #CLK23_LOW  x015B0020
PAT #CLK24_HIGH x013C00E4
PAT #CLK24_LOW  x015C001C
PAT #CLK25_HIGH x013D00E8
PAT #CLK25_LOW  x015D0018
PAT #CLK26_HIGH x013E00EC
PAT #CLK26_LOW  x015E0014
PAT #CLK27_HIGH x013F00F0
PAT #CLK27_LOW  x015F0010
PAT #CLK28_HIGH x014000F4
PAT #CLK28_LOW  x0160000C
PAT #CLK29_HIGH x014100F8
PAT #CLK29_LOW  x01610008
PAT #CLK30_HIGH x014200FC
PAT #CLK30_LOW  x01620004
PAT #CLK31_HIGH x014300FF
PAT #CLK31_LOW  x01630000
*
** Clock ripple patterns
*
PAT #CLOCK_00    b00000000000000000000000000000001
PAT #CLOCK_00L   b00000000000000000000000000000000
PAT #CLOCK_01    b00000000000000000000000000000010
PAT #CLOCK_01L   b00000000000000000000000000000000
PAT #CLOCK_02    b00000000000000000000000000000100
PAT #CLOCK_02L   b00000000000000000000000000000000
PAT #CLOCK_03    b00000000000000000000000000001000
PAT #CLOCK_03L   b00000000000000000000000000000000
PAT #CLOCK_04    b00000000000000000000000000010000
PAT #CLOCK_04L   b00000000000000000000000000000000
PAT #CLOCK_05    b00000000000000000000000000100000
PAT #CLOCK_05L   b00000000000000000000000000000000
PAT #CLOCK_06    b00000000000000000000000001000000
PAT #CLOCK_06L   b00000000000000000000000000000000
PAT #CLOCK_07    b00000000000000000000000010000000
PAT #CLOCK_07L   b00000000000000000000000000000000
PAT #CLOCK_08    b00000000000000000000000100000000
PAT #CLOCK_08L   b00000000000000000000000000000000
PAT #CLOCK_09    b00000000000000000000001000000000
PAT #CLOCK_09L   b00000000000000000000000000000000
PAT #CLOCK_10    b00000000000000000000010000000000
PAT #CLOCK_10L   b00000000000000000000000000000000
PAT #CLOCK_11    b00000000000000000000100000000000
PAT #CLOCK_11L   b00000000000000000000000000000000
PAT #CLOCK_12    b00000000000000000001000000000000
PAT #CLOCK_12L   b00000000000000000000000000000000
PAT #CLOCK_13    b00000000000000000010000000000000
PAT #CLOCK_13L   b00000000000000000000000000000000
PAT #CLOCK_14    b00000000000000000100000000000000
PAT #CLOCK_14L   b00000000000000000000000000000000
PAT #CLOCK_15    b00000000000000001000000000000000
PAT #CLOCK_15L   b00000000000000000000000000000000
PAT #CLOCK_16    b00000000000000010000000000000000
PAT #CLOCK_16L   b00000000000000000000000000000000
PAT #CLOCK_17    b00000000000000100000000000000000
PAT #CLOCK_17L   b00000000000000000000000000000000
PAT #CLOCK_18    b00000000000001000000000000000000
PAT #CLOCK_18L   b00000000000000000000000000000000
PAT #CLOCK_19    b00000000000010000000000000000000
PAT #CLOCK_19L   b00000000000000000000000000000000
PAT #CLOCK_20    b00000000000100000000000000000000
PAT #CLOCK_20L   b00000000000000000000000000000000
PAT #CLOCK_21    b00000000001000000000000000000000
PAT #CLOCK_21L   b00000000000000000000000000000000
PAT #CLOCK_22    b00000000010000000000000000000000
PAT #CLOCK_22L   b00000000000000000000000000000000
PAT #CLOCK_23    b00000000100000000000000000000000
PAT #CLOCK_23L   b00000000000000000000000000000000
PAT #CLOCK_24    b00000001000000000000000000000000
PAT #CLOCK_24L   b00000000000000000000000000000000
PAT #CLOCK_25    b00000010000000000000000000000000
PAT #CLOCK_25L   b00000000000000000000000000000000
PAT #CLOCK_26    b00000100000000000000000000000000
PAT #CLOCK_26L   b00000000000000000000000000000000
PAT #CLOCK_27    b00001000000000000000000000000000
PAT #CLOCK_27L   b00000000000000000000000000000000
PAT #CLOCK_28    b00010000000000000000000000000000
PAT #CLOCK_28L   b00000000000000000000000000000000
PAT #CLOCK_29    b00100000000000000000000000000000
PAT #CLOCK_29L   b00000000000000000000000000000000
PAT #CLOCK_30    b01000000000000000000000000000000
PAT #CLOCK_30L   b00000000000000000000000000000000
PAT #CLOCK_31    b10000000000000000000000000000000
PAT #CLOCK_31L   b00000000000000000000000000000000
PAT #CLOCK_LOW   b00000000000000000000000000000000
PAT #CLOCK_HI    b11111111111111111111111111111111
*
** Mux access patterns !!
*
PAT #MUXPAT00	 x016F001F		* P1 = Chan00 P2 = Chan00
PAT #MUXPAT01	 x016F011E		* P1 = Chan00 P2 = Chan01
PAT #MUXPAT02	 x016F021D		* P1 = Chan00 P2 = Chan02
PAT #MUXPAT03	 x016F031C		* P1 = Chan00 P2 = Chan03
PAT #MUXPAT04	 x016F041B		* P1 = Chan00 P2 = Chan04
PAT #MUXPAT05	 x016F051A		* P1 = Chan00 P2 = Chan05
PAT #MUXPAT06	 x016F0619		* P1 = Chan00 P2 = Chan06
PAT #MUXPAT07	 x016F0718		* P1 = Chan00 P2 = Chan07
PAT #MUXPAT08	 x016F0817		* P1 = Chan00 P2 = Chan08
PAT #MUXPAT09	 x016F0916		* P1 = Chan00 P2 = Chan09
PAT #MUXPAT10	 x016F0A15		* P1 = Chan00 P2 = Chan10
PAT #MUXPAT11	 x016F0B14		* P1 = Chan00 P2 = Chan11
PAT #MUXPAT12	 x016F0C13		* P1 = Chan00 P2 = Chan12
PAT #MUXPAT13	 x016F0D12		* P1 = Chan00 P2 = Chan13
PAT #MUXPAT14	 x016F0E11		* P1 = Chan00 P2 = Chan14
PAT #MUXPAT15	 x016F0F10		* P1 = Chan00 P2 = Chan15
PAT #MUXPAT16	 x016F100F		* P1 = Chan00 P2 = Chan16
PAT #MUXPAT17	 x016F110E		* P1 = Chan00 P2 = Chan17
PAT #MUXPAT18	 x016F120D		* P1 = Chan00 P2 = Chan18
PAT #MUXPAT19	 x016F130C		* P1 = Chan00 P2 = Chan19
PAT #MUXPAT20	 x016F140B		* P1 = Chan00 P2 = Chan20
PAT #MUXPAT21	 x016F150A		* P1 = Chan00 P2 = Chan21
PAT #MUXPAT22	 x016F1609		* P1 = Chan00 P2 = Chan22
PAT #MUXPAT23	 x016F1708		* P1 = Chan00 P2 = Chan23
PAT #MUXPAT24	 x016F1807		* P1 = Chan00 P2 = Chan24
PAT #MUXPAT25	 x016F1906		* P1 = Chan00 P2 = Chan25
PAT #MUXPAT26	 x016F1A05		* P1 = Chan00 P2 = Chan26
PAT #MUXPAT27	 x016F1B04		* P1 = Chan00 P2 = Chan27
PAT #MUXPAT28	 x016F1C03		* P1 = Chan00 P2 = Chan28
PAT #MUXPAT29	 x016F1D02		* P1 = Chan00 P2 = Chan29
PAT #MUXPAT30	 x016F1E01		* P1 = Chan00 P2 = Chan30
PAT #MUXPAT31	 x016F1F00		* P1 = Chan00 P2 = Chan31

**
*** Program segment starts here
**

#MAIN	LMR #WRITE16		* Set 16 bit write mode
	LPP #CLK00_HIGH		* point to the first clock channel value
	CAL #SETUP		* call the setup loop to setup the 64 DACs
#MXLOOP LPP #MUXPAT00
	CAL #RIPPL		* This is a very laborious manner of doing this !!  
	LPP #MUXPAT01
	CAL #RIPPL		* We could do this in a much simpler way if the sequencer
	LPP #MUXPAT02
	CAL #RIPPL		* would push the pattern pointer onto the stack during a CAL
	LPP #MUXPAT03
	CAL #RIPPL		* instruction !! 
	LPP #MUXPAT04
	CAL #RIPPL
	LPP #MUXPAT05
	CAL #RIPPL
	LPP #MUXPAT06
	CAL #RIPPL
	LPP #MUXPAT07
	CAL #RIPPL
	LPP #MUXPAT08
	CAL #RIPPL
	LPP #MUXPAT09
	CAL #RIPPL
	LPP #MUXPAT10
	CAL #RIPPL
	LPP #MUXPAT11
	CAL #RIPPL
	LPP #MUXPAT12
	CAL #RIPPL
	LPP #MUXPAT13
	CAL #RIPPL
	LPP #MUXPAT14
	CAL #RIPPL
	LPP #MUXPAT15
	CAL #RIPPL
	LPP #MUXPAT16
	CAL #RIPPL
	LPP #MUXPAT17
	CAL #RIPPL
	LPP #MUXPAT18
	CAL #RIPPL
	LPP #MUXPAT19
	CAL #RIPPL
	LPP #MUXPAT20
	CAL #RIPPL
	LPP #MUXPAT21
	CAL #RIPPL
	LPP #MUXPAT22
	CAL #RIPPL
	LPP #MUXPAT23
	CAL #RIPPL
	LPP #MUXPAT24
	CAL #RIPPL
	LPP #MUXPAT25
	CAL #RIPPL
	LPP #MUXPAT26
	CAL #RIPPL
	LPP #MUXPAT27
	CAL #RIPPL
	LPP #MUXPAT28
	CAL #RIPPL
	LPP #MUXPAT29
	CAL #RIPPL
	LPP #MUXPAT30
	CAL #RIPPL
	LPP #MUXPAT31
	CAL #RIPPL
	JMP #MXLOOP		* Loop endlessly

#RIPPL	LMR #WRITE16		* output the mux register value first
	LSR #CLKBRD
	LSR #DESLCT		* write out a value to the MUX register
	LRB #HOLDOFF		* Loop here to stabilize scope display
	DUS #HOLDDELAY		* wait for the MUX to settle
	LPE
	LDA #CLKPORT		* point to the on board address of the clock register
	LMR #WRITE32		* setup for 32 bit writes
	LPP #CLOCK_00		* point to the first clock value
	LRB #CLKLOOP		* loop for 32 hi/low clock value pairs for ripple clocks
	LSR #CLKBRD
	LSR #DESLCT		* write out high value
	LRB #DELAYLOOP
	DUS #DELAY
	LPE			* end of delay loop for high settle time
	IPP			* point to next value
	LPE			* end of loop for ripple clocks
	RET

#SETUP	LRB #CLKLOOP		* Start counting through the clock channels
	LSR #CLKBRD
	LSR #DESLCT		* write out the value
	IPP			* point to the next clock DAC channel value
	LRB #LOADLOOP
	DMS #DELAY		* Loop on the required delay
	LPE			* end of delay loop
	LPE			* end of clock channel loop
	RET			* Return for more punishment
**
*** End of program segment
**
