# CCD Board Testing Station Setup Mode File
#
# TEST SEQUENCE
# _7ii_
#
# HISTORY
# Version 1 - Peter Moore - 22 AUG 2005 - Adapted from _ccdlabSTIS system    
# Version 2 - Peter Moore - 28 SEP 2005 - Made to work with 8 outputs on fast machine
# Version 3 - Peter Moore - 24 APR 2006 - Made test image sizes smaller, set telemetry mode to 12 (bipolar)
# Version 4 - Peter Moore - 12 MAY 2006 - Slowed down initial acquisition to 250KPix/chan/sec
# Version 5 - Peter Moore - 14 MAY 2008 - changed AVP names to work with mnsnBrdTest system
#
# DESCRIPTION
# Tests the basic ADC function, offset noise values, all CDS switches held static
# Results should show a rms noise level below 3 ADU.
#
# This setup should always be loaded first since it sets up the basic operating 
# configuration for all additional tests.
#
# Attribute Name  = Value   #Comments
## Preamble - Kill the sequencer run flag if set
mcbSeqEnable=0
#
## Bring the Boards online with the system clocks
mcbBkplnSlct=0   # for a 6 slot backplane
mcbSysClkEn6=1   # Enable acquistion board System clock
#
## Reset the boards to condition them
ccdReset=1       # Reset the CCD acquisition board
#
## Setup some software defaults
ArrayID=ccdBoardTests
ArrayType=DUMMY
Filename=BrdTst   # Set an appropriate file name 
ImageFile=BrdTst  # Twice .. since the mec seems to like it !!
MosaicRows=8
MosaicCols=1
XPreScan=0        # Just need to read out a raw 2K x 2K image
XPostScan=0       # So set up for one array per video channel
YPostScan=0       # and 8 arrays mosaiced in X direction
ColBin=1         
RowBin=1         
NumOutputs=1     
OutputCfg=0       
PxlRows=512
PxlCols=512
ImageRows=512
ImageCols=512
XStart[]=1
YStart[]=1
FinDataType=32   # DHS_UINT four bytes 32 bits
FrmsPerRdOut=1   # number of readout for one simple exposure
CaptureMode=1    # capture mode 0=NORMAL, 1=SEP, 2=BLOCKREAD
ExpMode=0        # mode of the exposure
ProcessMode=1    # Processing mode -- Switch off the telemetry collection
ExpVector=1      # 1 = DO NORMAL READOUT WITH DC CLAMP + RESET ON  
                 # 2 = DO NORMAL READOUT WITH DC CLAMP ON         
                 # 4 = DO NORMAL READOUT                         
                 # 8 = DO FAST READOUT                         
                 #16 = DO BIAS RAMP TEST                           
                 #32 = DO FRONT END TESTS VIA DOP                  
AsyncVector=0    # Currently not used.
RawPxlSize=4     # number of Bytes in a raw pixel value
FinPxlSize=4     # number of Bytes in a finished pixel value
AvNameSIze=32    # Max character length of attribute name
AvValueSize=32   # Max character length of attribute value
AvCommentSize=64 # Max character length of attribute comment
#
## Sequencer attributes
seqRows=512          # Number of row data points
seqCols=512          # Number of column data points
seqSpan=16           # Number of steps in ramp
seqDacs=8            # Number of channels that are ramped
seqCdsDly=39         # Delay between CTC pulses (in sequencer clocks) value of 39 gives 250Kpix/chan/sec
seqDopDly=8          # Delay between CTC start and DOP going low (in sequencer clocks)
#
mcbSeqPreScaler=0
mcbContRun=0
#
## Telemetry mode setup
CCD_HVBIASTELMODE[]=12   # Internal Clock Mode, +/-10V full scale
#
## Bias voltages setup
CCD_HVBIASES[]=685  # Set all HV biases to nominal 5v 
#
## Offset voltages setup
CCD_VOFFSETS[]=1024 # Set all ADC offsets safe
#
## Video channels setup (Low Gain + WARP)
CCD_ADCCFG[]=2
#
## Initialize some of the ports
ccdCdsReg=0x136     # Kill all CDS activity
ccdDopReg=0         # Write zeros to DOP port
#
## Acquisition Board setup ##
ccdRedirect[0]=0
ccdRedirect[1]=1    # check out channel 3 at the present time
ccdRedirect[2]=2
ccdRedirect[3]=3
ccdRedirect[4]=4
ccdRedirect[5]=5
ccdRedirect[6]=6
ccdRedirect[7]=7
ccdRedirect[8]=0
ccdRedirect[9]=0
ccdRedirect[10]=0
ccdRedirect[11]=0
ccdRedirect[12]=0
ccdRedirect[13]=0
ccdRedirect[14]=0
ccdPixelXferCount=8 # Eight pixels to xfer for each CTC
ccdDataWidth=3      # Select 18 bit data mode
ccdPipePriority=0   # Only one acquisition board so highest priority
ccdPipelineEnbl=1   # Enable pipeline data writes
#
## Setup the voltages and enable to array
ccdHVBiasEnbl=1
ccdCdsEnbl=1        # Enable the CDS function
ccdCpldLedEnable=1  # Switch off the CPLD LEDs
#
## Diagnostics ...
ccdReset=1          # for temporary bug in the busy signal ...
mcbMpuSeqBusReq=1   # Led on mcb for sequencer bus req
ccdBrdSel=0         # Ditto for CCD board
ccdCdsLoad=1        # light the sky when cds load strobe present
LabSystem=1      # Kill long star date file names
