******************************************************
** PROJECT	: ORION II TEST SET
** TITLE	: EXEC PORTION OF ORIONII TEST SET CODE
** VERSION	: 008  ******** Experimental Code !  Experimental Code !   Experimental Code ! ******************
** DATE		: 07/08/2004
** AUTHOR	: PETER MOORE/JOHN GARCIA
** HISTORY	: 07/11/2003 PCM ORIGINAL VERSION.
**			: 07/21/2003     Source aligned to /monsoonhome/aladdin_test.
**			:                Backups in /waveforms/aladdinII.
**			: 07/25/2003 pcm Added fowler sampling + digital averaging
**			: 08/06/2003 pcm Added option to remove reset row strobe and make as normal read
**			: 11/12/2003 pcm Modified to run continous readouts when cmd reg bit set without 
**                          requiring a start exposure command to be sent. Removed the PAN 
**                          problem delay counter function
**			: 11/13/2003 pcm Added test counter for generating sequences of ctc commands
**			: 02/18/2004 pcm Added cancel at beginning to eliminate stray start exp flag hangs
**                           Coded the pattern memory data into source to exercise asm3 tool,
**                           Added co-add loop counter.
**                      : 04/07/2004 jpg modified for ORION II
**                           a) Alteration of FBIAS levels for ORION II
**                           b) Consolidation of pattern memory for easy changes
**                           c) Additional documentation of patterns in particular
**                           d) INIT subroutine modified to EXPLICITLY set up Fast Biases.
**                           d) Delays need close inspection!!!
**                      : 04/20/04 jpg modified for extra phiC2 pulse for col ref. cell and extra
**                            phiCS pulse to turn off TCend.  Does not trigger ADC for ref. cell.
**                      : 04/20/04 jpg added idle current shutdown during integration. 
**                            READ_INIT and READ_END modified.
**                      : 04/21/04  Digital averaging delay loops set for 6 us sampling (jpg).
**                      : 04/22/04  INIT subroutine set up to SELECT all 2048 row/column pairs (jpg).
**                      : 04/22/04  Additional delay (6 ms total) between IidleREF turn on and 
**                                  readout start for settling. (jpg)
**                      : 04/23/04  phiDES set for DHE low = ORION chip high in INIT subroutine
**                                  DESELECTION Section (jpg)
**                      : 04/26/04  Select all code section of INIT corrected. (jpg)
**                      : 04/27/04  ADC trig and dig. ave. delay loop added for column ref cell. (jpg)
**                      : 04/29/04  Extended delay between ADC conversions by 20 sequencer clock periods (jpg)
**                      : 04/30/04  Clock and Bias board moved to slot 8 (4th physical). (jpg)
**                      : 05/12/04  Extended width of row/col sysnc pulses and row/col clock underlap. (jpg)
**                      : 05/13/04  Enabled Row Reset Option (new FB pattern, delays) (jpg)
**                      : 05/19/04  VRSTR levels shifted from (0 to -4.0 v) to (-3.60 to -6.5 v) (jpg)
**
**
**                      : 07/13/04  Digital Average loop delay (us) assigned a label "DA_DELAY" for V004
**                                  Currently #DA_DELAY = 2 (jpg).
**
**                      : 08/25/04  DMS 5 added at beginning of Fowler loop as a hopefull cure for incomplete data
**                                  when using Monsoon Engineering Console.
**
**                      : 09/14/04  Changed so INIT (row/col deselection) subroutine run only at start up, not during normal
**                                  idle. (JPG)
**
**                      : 09/16/04  VrowOn low level changed from -4.2 volts to -4.5 volts.(JPG)
**
**                      : 11/03/04  Fixed DMS 5 at beginning of Fowler loop
**
**                      : 12/08/04  Delay after global reset changed to 20 ms from 2 ms to test neg.image.
**
**                      : 12/13/04  Global Reset pulse VRSTG extended from 20 us to 60 us for test.
**
**                      : 12/20/04 Delay after global reset changed to 10 ms from 20 ms
**                                  
** 
** DESCRIPTION : Does read operation for an image size determined by
**             : Rows=#rowloopsx(4rows/loop)x(2images/Fowler pair)
**             : Cols= 72 x 33 for 72 active IR Acq channels and 32 data + 1 reference Orion cols.
**             : Rows=4096 x (#Fowler pairs) for 512 rowloops, ORION
**             : Cols=2376 , ORION with column reference pixels at end for 33 cols and 72 active chan.
**
**             : To use digital averaging, set cntr 3 to the number of averages required
**             : then set bit 14 in the CMD register high (c w 1 0x102 4), then set the 
**             : same value loaded to cntr 3 to the IR Acquisition board control register
**             : bits 7 : 2. eg. for an average of 6 + pipeline writes + daughter board
**             : use c w 32 0xfffc 0x1b. for 4 averages use c w 32 0xfffc 0x13, etc.
**             : The only purpose of cntr 3 in this code is to provide sufficient delay
**             : for the adc's to cycle through the required averaging conversions.
**             :
**             : To enable the row reset read option (noise testing), set bit 15 in the CMD reg.
**
**             : Clock HIGH in this code = C/B board ouput HIGH (More +) = logical LOW (0) to ORION
**             : Clock LOW  in this code = C/B board ouput low  (less +) = logical HIGH (1) to ORION
**
** RESOURCES :
** CMD REG
** BIT
** 
** 0 => ALWAYS ONE. FORMS THE BRANCH UNCONDITIONAL INSTRUCTION.
** 1 => SYNCHRONIZATION BIT. SET BY EXTERNAL SIGNAL IN SLAVE MODE ELSE INTERNAL EFR REGISTER BIT. 
** 2 => INTEGRATION TIMER FLAG. INDICATES THAT INTEGRATION TIME HAS EXPIRED.
** 3 => SET BY THE START EXPOSURE ROUTINE (set by Start Exposure vector)
** 4 => DO FRAME READOUT (I.E. RST READ INTEGRATE READ)
** 5 => LOOP TEST TO TRIGGER CTC STROBES AT CERTAIN PERIODICITY
** 6 => DEBUG FSEH LOOP ON DEBUG LOOP CNTR
** 7 => DEBUG FSOL LOOP ON DEBUG LOOP CNTR
** 8 => DEBUG FSEL LOOP ON DEBUG LOOP CNTR
** 9 => DEBUG INIT LOOP ON DEBUG LOOP CNTR
** (set by direct write to Command Register at MCB addr 0x102)
** 12 => DO RESETS DURING IDLE MODE (command "c w 1 0x102 1")
** 13 => DO CONTINUOUS READOUTS     (command "c w 1 0x102 2")
** 14 => ENABLE DIGITAL AVERAGING   (command "c w 1 0x102 4")
** 15 => ENABLE ROW RESET READS     (command "c w 1 0x102 8")
**
** LOOP CNTR
** REGS
**  0  => ROW COUNTER = 512 USED BY THE READ SUBROUTINE (MCB addr 0x110)
**  2  => FOWLER SAMPLES = 1 TO 16
**  3  => DIGITAL AVERAGES REQUIRED (NOTE, MUST UPDATE THE START.CDL FILE TO CORRECTLY SET ADC'S)
**  4  => CO-ADD LOOP COUNTER.
**  5-12 => INIT loop counters for row/column pair selction/deselection.
** (0x011D) 13 => NUMBER OF CTC STROBES TO GENERATE FOR LOOPTST
** (0x011E) 14 => PERIOD BETWEEN CTC STROBES FOR LOOPTST. UNITS ARE 100NS * SEQUENCER PRESCALER 
** (0x011F) 15 => DEBUG COUNTER = USER DISCRETION; NUMBER OF TIMES THE SUBROUTINE IS CALLED (MCB addr 0x112)
********************************************************


**
** Constants definitions
**
DEF #KILL_EXPFLG    x00000001	        * Cancel start exposure flag using the EFR register 
DEF #STRT_INTCNTR   x00000002		* Start the integration time counter using the EFR register
DEF #STOP_INTCNTR   x00000004		* Stop the integration time counter using the EFR register
DEF #RESET		0	        * Mode register constant for board reset operation
DEF #READ		1	        * Mode register constant for read operation
DEF #WRITE16		2		* Mode register constant for 16 bit write operation
DEF #WRITE32		3		* Mode register constant for 32 bit write operation
DEF #ROW_LOOP		0		* Loop register 0 used as row counter. value=2048/4=512
DEF #COL_LOOP		1		* Loop register 1 used as column counter. value=16 
DEF #FOWLER_LOOP	2		* Loop register 2 used as Fowler read counter
DEF #DIGAVG_LOOP	3		* Loop register 3 used as digital average counter
DEF #COADD_LOOP		4		* Loop register 4 used as co-add loop counter

DEF #INIT_LOOP1         5               * Loop register 5 used as INIT loop counter (not used for now).

DEF #INIT_LOOP2         6               * Loop register 6 used as INIT loop counter (not used for now)
DEF #INIT_LOOP3         7               * Loop register 7 used as INIT loop counter (not used for now)
DEF #INIT_LOOP4         8               * Loop register 8 used as INIT loop counter (not used for now)
DEF #INIT_LOOP5         9               * Loop register 9 used as INIT loop counter (not used for now)
DEF #INTI_LOOP7         10              * Loop register 10 used as INIT loop counter(not used for now)
DEF #INTI_LOOP8         11              * Loop register 11 used as INIT loop counter(not used for now)
DEF #INTI_LOOP9         12              * Loop register 12 used as INIT loop counter(not used for now)

DEF #TST_CTC_CNT	13		* Test routine loop counters
DEF #TST_CTC_PRD	14
DEF #TST_LOOP		15
DEF #DESELECT		0		* select codes for boards
DEF #SELMCB		1		* MCB in slot 1 (1st physical)
DEF #SELCBB		8		* CLK & BIAS Board in slot 8 (4TH physical)
DEF #SELACQ		160		* IR ACQUISITION Boards in slots 32 and 128 (5th & 7th)
DEF #CLOCKREG		0		* Clock board address assignements - Clock register
DEF #FBIAS3210		1		* first bank of fast biases
DEF #FBIAS7654		2		* second bank of fast biases
DEF #ACQ_CTC		0		* Acquisition board addresses - Command to convert register
DEF #DA_DELAY           2               * Digital Average Loop Delay in us.

DEF #PAT_SEG_00 X00                     * Pattern Memory
DEF #PAT_SEG_20 X20
DEF #PAT_SEG_40 X40
DEF #PAT_SEG_60 X60
DEF #PAT_SEG_80 X80
DEF #PAT_SEG_A0 XA0
DEF #PAT_SEG_C0 XC0
DEF #PAT_SEG_E0 XE0
DEF #PAT_SEG_100 X100
DEF #PAT_SEG_120 X120
DEF #PAT_SEG_140 X140
DEF #PAT_SEG_160 X160
DEF #PAT_SEG_180 X180
DEF #PAT_SEG_1A0 X1A0
DEF #PAT_SEG_1C0 X1C0
DEF #PAT_SEG_1E0 X1E0
DEF #PAT_SEG_200 X200

**
** Pattern memory segment definitions
**

ORG PAT #PAT_SEG_00				     * Redundent code !
PAT #KILL_EXPFLG		#KILL_EXPFLG	     * Same label but different contexts 
PAT #STRT_INTCNTR		#STRT_INTCNTR	     * The definition earlier: a data value. The label here:
PAT #STOP_INTCNTR		#STOP_INTCNTR	     * a pattern memory address
PAT #IidleOFF                   x010400AE            * To turn OFF Col Idle current during integration
PAT #IidleON                    x0104008C            * To turn ON Col Idle current during readout. 


***********************  Fast Bias Assignment ORION TEST SET *******************************

ORG PAT #PAT_SEG_20                                  * Fast Bias 3-0: VROWON,VROWOFF,Spare,NC
PAT #SEG20_PAT01		x00000000            * FB3= 0.0, FB2= 0.0, FB1=0.0, FB0=0.0
PAT #SEG20_PAT02                xA1000000            * FB3=-4.2, FB2= 0.0, FB1=0.0, FB0=0.0


ORG PAT #PAT_SEG_40                                  * Fast Bias 7-4: VRTSR,VRSTG,VDDCL,VGGCL
PAT #SEG40_PAT01		x80808E79            * FB7= -3.60, FB6=-3.60, FB5=-4.00, FB4=-3.40
PAT #SEG40_PAT02                x80EF8E79            * FB7= -3.60, FB6=-6.5 , FB5=-4.00, FB4=-3.40
PAT #SEG40_PAT03                xEF808E79            * FB7=-6.5,   FB6=-3.60, FB5=-4.00, FB4=-3.40
*
*                                                     V_FB = -7.19 x (CODE/255)
*

*********************** Clock Assignment ORION TEST SET ************************************
*                                                           
*                                            Clock                   SS                                       
*                                            Name                    PP
*                                                                    AA
*                                                                    RR     R            D
*                                                    C           CC  EE     O R          ERR
*                                                    1           S2  21     E 1          S2S
*                                                   
*                                            Clock   3322_2222_2222_1111_1111_1100_0000_0000
*                                            Number  1098_7654_3210_9876_5432_1098_7654_3210


ORG PAT #PAT_SEG_60   * Used for INIT ROW Clocks
PAT #SEG60_PAT01		x8030780B          * 1000_0000_0011_0000_0111_1000_0000_1011      
PAT #SEG60_PAT02		x8030780A          * 1000_0000_0011_0000_0111_1000_0000_1010
PAT #SEG60_PAT03                x8030700B          * 1000_0000_0011_0000_0111_0000_0000_1011
PAT #SEG60_PAT04                x80307809          * 1000_0000_0011_0000_0111_1000_0000_1001
                      
PAT #SEG60_PAT0A                x8030780F          * 1000_0000_0011_0000_0111_1000_0000_1111
PAT #SEG60_PAT0B                x8030780E          * 1000_0000_0011_0000_0111_1000_0000_1110
PAT #SEG60_PAT0C                x8030780A          * 1000_0000_0011_0000_0111_1000_0000_1010

ORG PAT #PAT_SEG_80   * Used for READINIT Clocks
PAT #SEG80_PAT01		x8010780E          * 1000_0000_0001_0000_0111_1000_0000_1110
PAT #SEG80_PAT02		x8030780F          * 1000_0000_0011_0000_0111_1000_0000_1111
PAT #SEG80_PAT03		x8030700F          * 1000_0000_0011_0000_0111_0000_0000_1111

ORG PAT #PAT_SEG_A0   * Used for FSOH clocks   
PAT #SEGA0_PAT01		x8030780D          * 1000_0000_0011_0000_0111_1000_0000_1101  
PAT #SEGA0_PAT02		x8010780D          * 1000_0000_0001_0000_0111_1000_0000_1101
PAT #SEGA0_PAT03		x0030780D          * 0000_0000_0011_0000_0111_1000_0000_1101
PAT #SEGA0_PAT04		x8020780D          * 1000_0000_0010_0000_0111_1000_0000_1101
PAT #SEGA0_PAT05		x8030680D          * 1000_0000_0011_0000_0110_1000_0000_1101

ORG PAT #PAT_SEG_C0   * Used for FSEH Clocks
PAT #SEGC0_PAT01		x8030680D          * 1000_0000_0011_0000_0110_1000_0000_1101
PAT #SEGC0_PAT02		x8010680D          * 1000_0000_0001_0000_0110_1000_0000_1101
PAT #SEGC0_PAT03		x0030680D          * 0000_0000_0011_0000_0110_1000_0000_1101
PAT #SEGC0_PAT04		x8020680D          * 1000_0000_0010_0000_0110_1000_0000_1101
PAT #SEGC0_PAT05		x8030780F          * 1000_0000_0011_0000_0111_1000_0000_1111

ORG PAT #PAT_SEG_E0   * Used for FSOL Clocks
PAT #SEGE0_PAT01		x8030700F          * 1000_0000_0011_0000_0111_0000_0000_1111
PAT #SEGE0_PAT02		x8010700F          * 1000_0000_0001_0000_0111_0000_0000_1111
PAT #SEGE0_PAT03		x0030700F          * 0000_0000_0011_0000_0111_0000_0000_1111
PAT #SEGE0_PAT04		x8020700F          * 1000_0000_0010_0000_0111_0000_0000_1111
PAT #SEGE0_PAT05		x8030600F          * 1000_0000_0011_0000_0110_0000_0000_1111
		
ORG PAT #PAT_SEG_100   * Used for FSEL Clocks
PAT #SEG100_PAT01		x8030600F          * 1000_0000_0011_0000_0110_0000_0000_1111
PAT #SEG100_PAT02		x8010600F          * 1000_0000_0001_0000_0110_0000_0000_1111
PAT #SEG100_PAT03		x0030600F          * 0000_0000_0011_0000_0110_0000_0000_1111
PAT #SEG100_PAT04		x8020600F          * 1000_0000_0010_0000_0110_0000_0000_1111
PAT #SEG100_PAT05		x8030780F          * 1000_0000_0011_0000_0111_1000_0000_1111

ORG PAT #PAT_SEG_120   * Used for READ_END Clocks
PAT #SEG120_PAT01		x8010780E          * 1000_0000_0001_0000_0111_1000_0000_1110
PAT #SEG120_PAT02		x8030780F          * 1000_0000_0011_0000_0111_1000_0000_1111
**
**
**  Clocks 14, 13, 03 are actually don't cares. Used to be Q4phiDES, Q2phiDES, Q3phiDES 
**  in Aladdin code.
**
**
** BEGIN CODE SEGMENT
**
	LMR #WRITE32 				* SET 32 BIT WRITE MODE
	LPP #KILL_EXPFLG			* KILL EXTRANOUS START EXPOSURE FLAGS ON SEQUENCER 1st RUN
	LSR #SELMCB 				* WRITE TO THE EFR TO CANCEL ANY STRAY START EXP FLAGS
	LSR #DESELECT 				* CANCEL THE WRITE
#EXEC	CAL #INIT
#EXEC1	JCB #GOBABY 3		        * IF START EXPOSURE FLAG SET
	JCB #RSTLOOP 12			* ELSE IF RESET REQUIRED DURING IDLE
	JCB #READOUT 13			* DEBUG WAVEFORMS. CONTINUOUS READOUT IF BIT 13 IS SET
	JMP #EXEC1				* ELSE JUMP BACK TO EXEC
#GOBABY	LPP #KILL_EXPFLG 	        * KILL THE START EXP FLAG PATTERN = 0x00000001
	LMR #WRITE32 			* SET 32 BIT WRITE MODE
	LSR #SELMCB 			* WRITE TO THE EFR
	LSR #DESELECT 			* CANCEL THE WRITE
	JCB #READOUT 4 			* NORMAL RST READ INTEGRATE READ
	JCB #LPTST   5 			* SEND A STREAM OF CTC COMMANDS TO THE IR ACQUISITION
	JCB #DBGFSEH 6 			* DEBUG FSEH LOOP
	JCB #DBGFSOL 7 			* DEBUG FSOL LOOP
	JCB #DBGFSEL 8 			* DEBUG FSEL LOOP
	JCB #DBGINIT 9 			* DEBUG INIT LOOP
	JMP #EXEC1				* NO FLAGS SET, GO HOME.
*
#RSTLOOP CAL #RST 			* GO RESET THE ARRAY
        DMS 2                           * Reset every 2 ms if no delay inside RST subroutine
	JCB #EXEC1 0 			* GO BACK TO  EXEC1 NOT EXEC which calls INIT
*
* #READOUT LRB #COADD_LOOP	* START CO-ADD LOOP
#READOUT CAL #RST		 	* RESET THE ARRAY
        DMS 1				* DELAY 1 MILLISEC FOR RESET TO SETTLE
	LPP #STRT_INTCNTR 		* LOAD PATTERN POINTER FOR START INTEGRATION TIMER PATTERN = 0x00000002
	LMR #WRITE32 			* SET 32 BIT WRITE MODE
	LSR #SELMCB 			* WRITE TO THE EFR
	LSR #DESELECT 			* CANCEL THE WRITE
	CAL #READ 			* READOUT THE ARRAY
#INTWAIT JCB #RDOUT2 2 		* WAIT FOR INTEGRATION TIMER
	JCB #INTWAIT 0
#RDOUT2 LPP #STOP_INTCNTR 	* LOAD PATTERN POINTER TO STOP INTEGRATION TIMER PATTERN = 0x00000004
	LMR #WRITE32 			* SET 32 BIT WRITE MODE
	LSR #SELMCB 			* WRITE TO THE EFR
	LSR #DESELECT 			* CANCEL THE WRITE
	CAL #READ 		        * READOUT THE ARRAY
*	LPE				* END OF CO-ADD LOOP
	JCB #READOUT 13 		* CONTINUOUS READOUT IF BIT 13 IS SET ("c w 1 0x102 2")
	JMP #EXEC1	 			* GO BACK TO SLEEP
*
#READ LRB #FOWLER_LOOP		* LOOP FOR N FOWLER SAMPLES
        DMS 5                           * Delay
       	CAL #READINIT 			* SETUP THE CLOCKS FOR READOUT
	LRB #ROW_LOOP 			* LOOP N ROW COUNTS (NOMINALLY 512 for ORION)
	CAL #FSOH
	CAL #FSEH
	CAL #FSOL
	CAL #FSEL
	LPE 				* END OF ROW COUNTER LOOP
	CAL #READEND 			* GO BACK TO INTEGRATION STATE
	LPE				* END OF FOWLER LOOP
	RET
*
#LPTST  LMR #WRITE32 		* SET 32 BIT WRITE MODE
	LPP 0				* PATTERN POINTER SET TO 0 (IRRELEVENT REALLY BUT GOOD FORM)
	LDA #ACQ_CTC			* DEVICE ADDRESS SET TO 0
	LRB #TST_CTC_CNT		* LOOP FOR NUMBER OF CTC STROBES REQUESTED
	LSR #SELACQ 			* TRIGGER ADC
	LSR #DESELECT
	LRB #TST_CTC_PRD		* WAIT FOR SPECIFIED NUMBER OF CLOCK CYCLES BETWEEN STROBES
	LPE
	LPE						* END OF TEST LOOP
	JMP #EXEC1
*
#DBGFSOH LRB #TST_LOOP 		* DEBUG LOOP COUNTER
	CAL #FSOH 		* CALL THE SUBROUTINE
	LPE
	JCB #EXEC1 0 		* GO BACK HOME
*
#DBGFSEH LRB #TST_LOOP 		* DEBUG LOOP COUNTER
	CAL #FSEH 		* CALL THE SUBROUTINE
	LPE
	JMP #EXEC1 	 	* GO BACK HOME
*
#DBGFSOL LRB #TST_LOOP 		* DEBUG LOOP COUNTER
	CAL #FSOL 		* CALL THE SUBROUTINE
	LPE
	JMP #EXEC1 	 	* GO BACK HOME
*
#DBGFSEL LRB #TST_LOOP 		* DEBUG LOOP COUNTER
	CAL #FSEL 		* CALL THE SUBROUTINE
	LPE
	JCB #EXEC1 0 		* GO BACK HOME
#DBGINIT LRB #TST_LOOP 		* DEBUG LOOP COUNTER
	CAL #INIT 		* CALL THE SUBROUTINE
	LPE
	JMP #EXEC1	 	* GO BACK HOME
*
**********************************************************
* DUMMY SUBROUTINES AS PLACE HOLDERS ONLY *
* COMMENT THESE OUT WHEN COMBINING THE CODE SEGMENTS *
**********************************************************
* #RST RET
* #INIT RET
* #READINIT RET
* #FSOH RET
* #FSEH RET
* #FSOL RET
* #FSEL RET
* #READEND RET
******************************************************
** PROJECT : ALADDIN
** TITLE : INIT SUBROUTINE
** VERSION : 0.1
** DATE : 07/12/2003
** AUTHOR : JOHN GARCIA, GUSTAVO RAHMER
** HISTORY : 07/12/2003 ORIGINAL VERSION.
** DESCRIPTION : Selects/Deselects Row/Col pairs
** RESOURCES : loop registers 5 - 12 at MCB 0x0115 - 0x011C
********************************************************

* 1  EXPLICITLY SET UP FAST BIASES (new)
#INIT   LMR #WRITE32
        LDA #FBIAS3210 				* FBias 3,2,1,0: VROWON,VROWOFF, Spare, NC
	LPP #SEG20_PAT01                        * VROWON high
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
	LDA #FBIAS7654                          * FBIAS 7,6,5,4: VRSTR,VRSTG,VDDCL,VGGCL
	LPP #SEG40_PAT01 		        * 
	LSR #SELCBB                             * 
	LSR #DESELECT                           * Aladdin: VDDCL low, VGGCL high
	LSR #SELCBB
	LSR #DESELECT
        DUS 10

* 2  SELECT ALL ROW/COLUMN PAIRS PRIOR TO DESELECTING ANY

        LDA #CLOCKREG
	LPP #SEG60_PAT0A			* Clocks: All high
	LSR #SELCBB
	LSR #DESELECT
	DUS 2 					* delay 2us
* 3     
	LPP #SEG60_PAT0B 			* Clocks: phiRS low (intitialize register)
	LSR #SELCBB                             
	LSR #DESELECT
        DUS 5                                   * Delay 5 us

        LDA #CLOCKREG
	LPP #SEG60_PAT0C			* Clocks: phiDES low
	LSR #SELCBB
	LSR #DESELECT
	DUS 30 					* delay 30 us

        LDA #CLOCKREG
	LPP #SEG60_PAT0B			* Clocks: phiDES high
	LSR #SELCBB
	LSR #DESELECT
	DUS 5 					* delay 5 us

* 4  
        LDA #CLOCKREG
	LPP #SEG60_PAT0A			* Clocks: All high
	LSR #SELCBB
	LSR #DESELECT
	DUS 2 					* delay 2us
        
**************************
*DESELECTION SECTION
**************************        
*       LDA #CLOCKREG
*      	LPP #SEG60_PAT01			* Clocks: All high, except phiDES
*	LSR #SELCBB                             * PAT 0-4 in SEG60 leave phiDES low
*	LSR #DESELECT
*	DUS 2
*
*    
*       LDA #CLOCKREG
*	LPP #SEG60_PAT03			* Clocks: phiR1 low (initialize register)
*	LSR #SELCBB
*	LSR #DESELECT
*	DUS 2
*    
*       LRB #INIT_LOOP1                         * Clock row register until a deselect needed
*                                               * phiROE is a don't care, always high here.
*                                               * VROWON always high (0.0 v) so no rows in analog
*                                               * section of MUX are enabled.
*       LDA #CLOCKREG                           *
*	LPP #SEG60_PAT01			* Clocks: All high
*	LSR #SELCBB
*	LSR #DESELECT
*	DUS 2
*       LDA #CLOCKREG
*	LPP #SEG60_PAT04			* Clocks: phiR2 low
*	LSR #SELCBB
*	LSR #DESELECT
*	DUS 20
*       Could end loop and deselect row/col pair here, then restart loop 
*       LDA #CLOCKREG
*	LPP #SEG60_PAT01			* Clocks: All high
*	LSR #SELCBB
*	LSR #DESELECT
*	DUS 2
*        LDA #CLOCKREG
*	LPP #SEG60_PAT03			* Clocks: phiR1 low
*	LSR #SELCBB
*	LSR #DESELECT
*	DUS 20
*       Could end loop and deselect row/col pair here, then restart loop
*
*        LPE                                     * End of loop
**********************
*END DESELECTION SECTION
**********************
*       LDA #CLOCKREG
*	LPP #SEG60_PAT01			* Clocks: All high
*	LSR #SELCBB
*	LSR #DESELECT
*	DUS 2        
*        
*	LPP #SEG60_PAT02 			* Clocks: phiRS low (turn off tRend)
*	LSR #SELCBB
*	LSR #DESELECT
*       DUS 2
*
*       LDA #CLOCKREG
*	LPP #SEG60_PAT01			* Clocks: All high
*	LSR #SELCBB
*	LSR #DESELECT
*	DUS 20        
*
* 
* end of subroutine
	RET
**********************************************************
*ALADDIN SEQUENCE CODE
*Aladdin_RST.asm
*Toggles Fast Bias VRSTG between frame readouts
*Comes before READ_INIT
*Comes after READ_END
*Codes only columns I through M of READ_END (formerly RST/INT) spreadsheet
*Assumes Fast Biases and Clocks have been set to
*the proper states by READ_END
**********************************************************
#RST	LDA #FBIAS7654 				 * POINT TO FBIAS 7654
*Set Fast Bias VRSTG low
	LPP #SEG40_PAT02 		
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
*Delay 20 us, 150 ns for instructions
	DUS 100                                   * Changed to 60 us delay on 12/13/04 for test
*Set Fast Bias VRSTG high
	LPP #SEG40_PAT01 		
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
        DMS 10                        * ****** For Neg Image Test Only, normally no delay *********
	RET
*END RST
**********************************************************
*ALADDIN SEQUENCE CODE
*Aladdin_READ_INIT.asm
*Initializes slow and fast shift registers
*Comes before FSOH on FIRST row readout
*Comes after RST or INT
*Codes only columns I through M of READ_END spreadsheet
*Assumes Fast Biases and Clocks have been set to
*the proper states by RST or INT.
*********************************************************				       * DELAY TOTALS 550ns COMING IN

*  Turn ON IidleREF (Bias04 @ 0x0104) during readout only
#READINIT LMR #WRITE16
	LPP #IidleON
	LSR #SELCBB
        LSR #DESELECT
        LMR #WRITE32
        DMS 6
	LDA #CLOCKREG			       * POINT TO CLOCKS
*Set clocks PhiSS and PhiFS low
	LPP #SEG80_PAT01 		       * (8010780E)
	LSR #SELCBB
	LSR #DESELECT
*Delay 2100 ns, 100 ns for instructions
	DSC 40
*Set clocks PhiSS and PhiFS high
	LPP #SEG80_PAT02 		       * (8030780F)
	LSR #SELCBB
	LSR #DESELECT
*Delay 2100 ns, 100 ns for instructions
	DSC 40
*Set clock PhiS1 low
	LPP #SEG80_PAT03 		       * (8030700F)
	LSR #SELCBB
	LSR #DESELECT
*Delay 2100 ns, 100 ns for instructions
	DSC 40
*Set clock PhiS1 high
	LPP #SEG80_PAT02 		       * (8030780F)
	LSR #SELCBB
	LSR #DESELECT
*Delay 450 ns, 100 ns for instructions
	DSC 7
	RET
*END READINIT
**********************************************************
* SUBROUTINE FSOH *
* FAST SHIFT,ODD ROW, phiS1 HIGH *
**********************************************************
#FSOH LMR #WRITE32
*1 Initialize the clock registers
        DSC 40
	LPP #SEGA0_PAT01 			* CLOCKS: phiR2 LOW
	LDA #CLOCKREG
	LSR #SELCBB
	LSR #DESELECT
*2 update fast bias group 2
	LPP #SEG40_PAT01 			* FBIAS 7,6,5,4: VRSTR,VRSTG,VDDCL,VGGCL
	LDA #FBIAS7654                          * 
	LSR #SELCBB                             * 
	LSR #DESELECT                           * Aladdin: VDDCL low, VGGCL high
	LSR #SELCBB
	LSR #DESELECT
*3 update fast bias group 1                     * FBIAS 3,2,1,0: VROWON, VROWOFF, Spare, NC
	LPP #SEG20_PAT02 		        * VROWON: high to low
	LDA #FBIAS3210				* Address fast bias group 1
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
	JCB #FSOH1 15		                * Are we doing row reset reads ? 
	DSC 6
	JCB #FSOH2 0		                * Skip the row reset sig
*4 update the fast bias 2
#FSOH1	DSC 1
	LPP #SEG40_PAT03 		        * Set VRSTR low
	LDA #FBIAS7654			        * Address fast bias group 2
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
*5 update the clock pattern
#FSOH2	DSC 40
        LDA #CLOCKREG		                * Address the clock register
	LPP #SEGA0_PAT02 			* CLOCKS : phiCS LOW
	LSR #SELCBB
	LSR #DESELECT
*6 initial clock pattern
	DSC 20
	LPP #SEGA0_PAT01 			* CLOCKS : phiCS HIGH
	LSR #SELCBB
	LSR #DESELECT
*7 new clock pattern
	DSC 20
	LPP #SEGA0_PAT03 			* CLOCKS : phiC1 LOW
	LSR #SELCBB
	LSR #DESELECT
*8 initial clock pattern
	DSC 20
	LPP #SEGA0_PAT01 			* CLOCKS : phiC1 HIGH
	LSR #SELCBB
	LSR #DESELECT
*9 Loop 16 times on the following code segment
	DSC 80
	LRB #COL_LOOP
	LPP #SEGA0_PAT04 			* CLOCKS : phiC2 LOW
	LSR #SELCBB
	LSR #DESELECT
	DSC 120                                 * changed from DSC 100
	LSR #SELACQ 		                * TRIGGER ADC
	LSR #DESELECT
	JCB #FSOH3 14		                * IF DIGITAL AVERAGING SET
	JMP #FSOH4			        * ELSE CONTINUE WITHOUT DELAY
#FSOH3 LRB #DIGAVG_LOOP	                        * DELAY FOR #DA_DELAY us / DIGITAL AVERAGE
	DUS #DA_DELAY
	LPE					* END OF DELAY LOOP
*10
#FSOH4	DSC 7
	LPP #SEGA0_PAT01 			* CLOCKS: phiC2 HIGH
	LSR #SELCBB
	LSR #DESELECT
*11
	DSC 20
	LPP #SEGA0_PAT03 		        * CLOCKS:phiC1 LOW
	LSR #SELCBB
	LSR #DESELECT
	DSC 120                                 * changed from DSC 100
	LSR #SELACQ 		                * TRIGGER ADCS
	LSR #DESELECT
	JCB #FSOH5 14		                * IF DIGITAL AVERAGING SET
	JMP #FSOH6			        * ELSE CONTINUE WITHOUT DELAY
#FSOH5 LRB #DIGAVG_LOOP	                        * DELAY FOR #DA_DELAY us / DIGITAL AVERAGE
	DUS #DA_DELAY
	LPE					* END OF DELAY LOOP
#FSOH6	DSC 7
	LPP #SEGA0_PAT01 			* CLOCKS: phiC1 HIGH
	LSR #SELCBB
	LSR #DESELECT
*12
	DSC 20
	LPE

*Extra Column Clock transition for Orion ref cell 
	LPP #SEGA0_PAT04 			* CLOCKS : phiC2 LOW
	LSR #SELCBB
	LSR #DESELECT                          
	DSC 120                                 * changed from DSC 100
	LSR #SELACQ 		                * TRIGGER ADCs
	LSR #DESELECT
        JCB #FSOH7 14		                * IF DIGITAL AVERAGING SET
	JMP #FSOH8			        * ELSE CONTINUE WITHOUT DELAY
#FSOH7  LRB #DIGAVG_LOOP	                * DELAY FOR #DA_DELAY us / DIGITAL AVERAGE
	DUS #DA_DELAY
	LPE
#FSOH8  DSC 7					* END OF DELAY LOOP
	LPP #SEGA0_PAT01 			* CLOCKS: phiC2 HIGH
	LSR #SELCBB
	LSR #DESELECT
	DSC 12
        LPP #SEGA0_PAT02                        * CLOCKS: phiCS low
	LSR #SELCBB
	LSR #DESELECT
	DSC 20
	LPP #SEGA0_PAT01                        * CLOCKS: phiCS high
	LSR #SELCBB
	LSR #DESELECT
*End extra clock transition

	JCB #FSOH9 15                   
	LPP #SEG40_PAT01		        * Load FB7654 end pattern if normal read 
	JMP #FSOH10                             * LPP incorrectly pointed to h78 in AladdinV006
*13 update the fast bias 2
#FSOH9	LPP #SEG40_PAT03 		        * VRSTR still low, VRSTG, VDDCL, VGGCL const.
#FSOH10	LDA #FBIAS7654
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
*14 update the fast bias 1
	DSC 2
	LPP #SEG20_PAT01 		        * FBIAS3210: VROWON: low to high
	LDA #FBIAS3210
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
*15 update the fast bias 2
	DSC 8
	LPP #SEG40_PAT01 			* Set VRSTR high
	LDA #FBIAS7654
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
*16 update the clock pattern
	DSC 40                                  * delay 2us
	LPP #SEGA0_PAT05 			* CLOCK : phiROE LOW
	LDA #CLOCKREG
	LSR #SELCBB
	LSR #DESELECT
	RET
****************************************************** 
** PROJECT : ALADDIN
** TITLE : FSEH SUBROUTINE (Fast Shift, Even row, phiS1 High)
** VERSION : 0.1
** DATE : 07/11/2003
** AUTHOR : GUSTAVO RAHMER
** HISTORY : 07/11/2003 ORIGINAL VERSION.
** DESCRIPTION :
** RESOURCES :
********************************************************
* 0
#FSEH DSC 40 			                * delay 250ns
* 1
	LDA #FBIAS3210 				* FBias 3,2,1,0: VROWON,VROWOFF, Spare, NC
	LPP #SEG20_PAT01                        * 
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
	LDA #FBIAS7654                          * FBIAS 7,6,5,4: VRSTR,VRSTG,VDDCL,VGGCL
	LPP #SEG40_PAT01 		        * 
	LSR #SELCBB                             * 
	LSR #DESELECT                           * Aladdin: VDDCL low, VGGCL high
	LSR #SELCBB
	LSR #DESELECT
	LDA #CLOCKREG
        DSC 40 		                
	LPP #SEGC0_PAT01                        * Clocks: phiROE high to low
	LSR #SELCBB
	LSR #DESELECT
* 2
	LDA #FBIAS3210                 
	LPP #SEG20_PAT02		        * Fbias3,2,1,0: VROWON  high to low 
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
	JCB #FSEH1 15		                * Are we doing row reset reads ? 
	DSC 6
	JMP #FSEH2			        * Skip the row reset sig
* 3
#FSEH1	DSC 1 			                * delay 425ns
	LDA #FBIAS7654
	LPP #SEG40_PAT03 			* Set VRSTR low
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
* 4
#FSEH2	DSC 40 			                * delay 
	LDA #CLOCKREG
	LPP #SEGC0_PAT02 			* Clocks: phiCS low
	LSR #SELCBB
	LSR #DESELECT
* 5
	DSC 20
	LPP #SEGC0_PAT01 			* Clocks: phiCS high
	LSR #SELCBB
	LSR #DESELECT
* 6
	DSC 20 				        * delay 175ns
	LPP #SEGC0_PAT03 			* Clocks: phiC1 low
	LSR #SELCBB
	LSR #DESELECT
* 7
	DSC 20 				        * delay 175ns
	LPP #SEGC0_PAT01		        * Clocks: phiC1 high
	LSR #SELCBB
	LSR #DESELECT
* 8
	DSC 80 				        * delay 4125ns
	LRB #COL_LOOP 		                * Loop 16 times over columns (counter 1)
	LPP #SEGC0_PAT04		        * Clocks: phiC2 low
	LSR #SELCBB
	LSR #DESELECT
	DSC 120 			        * delay 6000ns changed from DSC 100
	LSR #SELACQ 		                * trigger CTC on Acq board 
	LSR #DESELECT                           * (by writing to dev addr 0)
	JCB #FSEH3 14		                * IF DIGITAL AVERAGING SET
	JMP #FSEH4			        * ELSE CONTINUE WITHOUT DELAY
#FSEH3  LRB #DIGAVG_LOOP	                * DELAY FOR #DA_DELAY us / DIGITAL AVERAGE
	DUS #DA_DELAY
	LPE					* END OF DELAY LOOP
* 9
#FSEH4	DSC 7 			                * delay 625ns
	LPP #SEGC0_PAT01 			* Clocks: phiC2 high
	LSR #SELCBB
	LSR #DESELECT
	DSC 20 				        * delay 250ns
* 10
	LPP #SEGC0_PAT03 			* Clocks: phiC1 low
	LSR #SELCBB
	LSR #DESELECT
	DSC 120 			        * delay 6000ns changed from DSC 100
	LSR #SELACQ 		                * trigger CTC on Acq board 
	LSR #DESELECT                           * (by writing to dev addr 0)
	JCB #FSEH5 14		                * IF DIGITAL AVERAGING SET
	JMP #FSEH6			        * ELSE CONTINUE WITHOUT DELAY
#FSEH5 LRB #DIGAVG_LOOP	                        * DELAY FOR #DA_DELAY us / DIGITAL AVERAGE
	DUS #DA_DELAY
	LPE					* END OF DELAY LOOP
* 11
#FSEH6	DSC 7 			                * delay 625ns
	LPP #SEGC0_PAT01 			* Clocks: phiC1 high
	LSR #SELCBB
	LSR #DESELECT   
	DSC 20 				        * delay 250ns
	LPE 				        * end of internal loop

*Extra Column Clock transition for Orion ref cell 
	LPP #SEGC0_PAT04 			* CLOCKS : phiC2 LOW
	LSR #SELCBB
	LSR #DESELECT
	DSC 120                                 * changed from DSC 100
        LSR #SELACQ 		                * trigger CTC on Acq board 
	LSR #DESELECT                           * (by writing to dev addr 0)
	JCB #FSEH7 14		                * IF DIGITAL AVERAGING SET
	JMP #FSEH8			        * ELSE CONTINUE WITHOUT DELAY
#FSEH7 LRB #DIGAVG_LOOP	                        * DELAY FOR #DA_DELAY us / DIGITAL AVERAGE
	DUS #DA_DELAY
	LPE					* END OF DELAY LOOP
* 
#FSEH8	DSC 7 			                * delay 625ns

	LPP #SEGC0_PAT01 			* CLOCKS: phiC2 HIGH
	LSR #SELCBB
	LSR #DESELECT
	DSC 12
        LPP #SEGC0_PAT02                        * CLOCKS: phiCS low
	LSR #SELCBB
	LSR #DESELECT
	DSC 20
	LPP #SEGC0_PAT01                        * CLOCKS: phiCS high
	LSR #SELCBB
	LSR #DESELECT
*End extra clock transition

	JCB #FSEH9 15
	LPP #SEG40_PAT01		        * Load end pattern if normal read 
	JCB #FSEH10 0
* 12
#FSEH9	LPP #SEG40_PAT03 		        * Fbias7654: VRSTR low, VRSTG, VGGCL,VDDCL const
#FSEH10	LDA #FBIAS7654
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
* 13
	DSC 2 				        * delay 425ns
	LDA #FBIAS3210
	LPP #SEG20_PAT01 			* Fbias3210: VROWON low to high
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
	DSC 8 				        * delay 775ns
* 14
	LDA #FBIAS7654
	LPP #SEG40_PAT01 	                * Fbias7654: VRSTR goes high
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
	DSC 40 				        * delay 2us
* 15
	LDA #CLOCKREG 		                * Clocks: All high
	LPP #SEGC0_PAT05
	LSR #SELCBB
	LSR #DESELECT
* end of FSEH subroutine
	RET
**********************************************************
* SUBROUTINE FSOL *
* FAST SHIFT,ODD ROW,PHIS1 LOW *
**********************************************************
#FSOL   DSC 40                                   * Was LMR #WRITE32
*1 Initialize the clock registers
	LPP #SEGE0_PAT01 		        *CLOCK: phiR1 LOW
	LDA #CLOCKREG
	LSR #SELCBB
	LSR #DESELECT
*2 update  FBIAS7654
	LPP #SEG40_PAT01 			* FBIAS 7,6,5,4: VRSTR,VRSTG,VDDCL,VGGCL
	LDA #FBIAS7654                          * 
	LSR #SELCBB                             * 
	LSR #DESELECT                           * Aladdin: VDDCL low, VGGCL high
	LSR #SELCBB
	LSR #DESELECT
*3 update the FBIAS3210                         * FBIAS 3,2,1,0: VROWON, VROWOFF, Spare, NC
	LPP #SEG20_PAT02 			* FBIAS 3: VROWON high to low
	LDA #FBIAS3210                          
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
	JCB #FSOL1 15		                * Are we doing row reset reads ? 
	DSC 6
	JMP #FSOL2			        * Skip the row reset sig
*4 update the fast bias 2
#FSOL1	DSC 1
	LPP #SEG40_PAT03 			* Set VRSTR low
	LDA #FBIAS7654
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
*5 update the clock pattern
#FSOL2	DSC 40
	LDA #CLOCKREG
	LPP #SEGE0_PAT02 			* CLOCKS : phiCS LOW
	LSR #SELCBB
	LSR #DESELECT
*6 initial clock pattern
	DSC 20
	LPP #SEGE0_PAT01 			* CLOCKS : phiCS HIGH
	LSR #SELCBB
	LSR #DESELECT
*7 new clock pattern
	DSC 20
	LPP #SEGE0_PAT03 			* CLOCKS : phiC1 LOW
	LSR #SELCBB
	LSR #DESELECT
*8 initial clock pattern
	DSC 20
	LPP #SEGE0_PAT01 			* CLOCKS : phiC1 HIGH
	LSR #SELCBB
	LSR #DESELECT
*9 Loop 16 times on the following code segment
	DSC 80
	LRB #COL_LOOP
	LPP #SEGE0_PAT04 			* CLOCKS : phiC2 LOW
	LSR #SELCBB
	LSR #DESELECT
	DSC 120                                 * changed from DSC 100
	LSR #SELACQ 		                * TRIGGER ADCs
	LSR #DESELECT
	JCB #FSOL3 14		                * IF DIGITAL AVERAGING SET
	JMP #FSOL4			        * ELSE CONTINUE WITHOUT DELAY
#FSOL3 LRB #DIGAVG_LOOP	                        * DELAY FOR #DA_DELAY us / DIGITAL AVERAGE
	DUS #DA_DELAY
	LPE					* END OF DELAY LOOP
*10
#FSOL4	DSC 7
	LPP #SEGE0_PAT01 			* CLOCKS : phiC2 HIGH
	LSR #SELCBB
	LSR #DESELECT
*11
	DSC 20
	LPP #SEGE0_PAT03 		        * CLOCKS :phiC1 LOW
	LSR #SELCBB
	LSR #DESELECT
	DSC 120                                 * changed from DSC 100
	LSR #SELACQ 		                * TRIGGER ADCs
	LSR #DESELECT
	JCB #FSOL5 14		                * IF DIGITAL AVERAGING SET
	JMP #FSOL6			        * ELSE CONTINUE WITHOUT DELAY
#FSOL5 LRB #DIGAVG_LOOP                         * DELAY FOR #DA_DELAY us / DIGITAL AVERAGE
	DUS #DA_DELAY
	LPE					* END OF DELAY LOOP
#FSOL6	DSC 7
*12
	LPP #SEGE0_PAT01 			* CLOCKS: phiC1 HIGH
	LSR #SELCBB
	LSR #DESELECT
	DSC 20
	LPE

*Extra Column Clock transition for Orion ref cell
	LPP #SEGE0_PAT04 			* CLOCKS : phiC2 LOW
	LSR #SELCBB
	LSR #DESELECT
	DSC 120                                 * changed from DSC 100
        LSR #SELACQ 		                * TRIGGER ADCs
	LSR #DESELECT
	JCB #FSOL7 14		                * IF DIGITAL AVERAGING SET
	JMP #FSOL8			        * ELSE CONTINUE WITHOUT DELAY
#FSOL7 LRB #DIGAVG_LOOP                         * DELAY FOR #DA_DELAY us / DIGITAL AVERAGE
	DUS #DA_DELAY
	LPE					* END OF DELAY LOOP
#FSOL8	DSC 7

	LPP #SEGE0_PAT01 			* CLOCKS: phiC2 HIGH
	LSR #SELCBB
	LSR #DESELECT
	DSC 12
        LPP #SEGE0_PAT02                        * CLOCKS: phiCS low
	LSR #SELCBB
	LSR #DESELECT
	DSC 20
	LPP #SEGE0_PAT01                        * CLOCKS: phiCS high
	LSR #SELCBB
	LSR #DESELECT
*End extra clock transition

	JCB #FSOL9 15                           * jump if doing row resets
	LPP #SEG40_PAT01			* Load end pattern if normal read 
	JMP #FSOL10                              * Aladdin: VDDCL high, VGGCL low, VRSTR high
*13 update the fast bias block 2
#FSOL9	LPP #SEG40_PAT03                        * FBIAS7654: VRSTR low, VRSTG, VDDCL, VGGCL const 
#FSOL10	LDA #FBIAS7654
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
*14 update the fast bias block 1
	DSC 2
	LPP #SEG20_PAT01		        * FBIAS3210: VROWON low to high
        LDA #FBIAS3210
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
*15 update the fast bias block 2
	DSC 8
	LPP #SEG40_PAT01		        *FBIAS7654: Set VRSTR high
	LDA #FBIAS7654
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
*16 update the clock pattern
	DSC 40
	LPP #SEGE0_PAT05 			* CLOCK : phiROE LOW
	LDA #CLOCKREG
	LSR #SELCBB
	LSR #DESELECT
	RET
******************************************************
** PROJECT : ALADDIN
** TITLE : FSEL SUBROUTINE
** VERSION : 0.1
** DATE : 07/11/2003
** AUTHOR : GUSTAVO RAHMER
** HISTORY : 07/11/2003 ORIGINAL VERSION.
** DESCRIPTION :
** RESOURCES :
********************************************************
* 0
#FSEL   DSC 40			                * delay 250ns
* 1
	LDA #FBIAS3210 				* FBIAS 3,2,1,0: VROWON, VROWOFF, Spare, NC
	LPP #SEG20_PAT01                        * 
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
	LDA #FBIAS7654			        * FBIAS 7,6,5,4: VRSTR,VRSTG,VDDCL,VGGCL
	LPP #SEG40_PAT01                        * 
	LSR #SELCBB                             * 
	LSR #DESELECT                           * Aladdin: VDDCL low, VGGCL high
	LSR #SELCBB
	LSR #DESELECT
	LDA #CLOCKREG 		                
	LPP #SEG100_PAT01                       * Clocks: phiROE, phiR1 low
	LSR #SELCBB
	LSR #DESELECT
* 2
	LDA #FBIAS3210  		         
	LPP #SEG20_PAT02                        * Fbias3210: VROWON high to low
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
	JCB #FSEL1 15		                * Are we doing row reset reads ? 
	DSC 6
	JMP #FSEL2			        * Skip the row reset sig
* 3
#FSEL1	DSC 1 			                * delay
	LDA #FBIAS7654			         
	LPP #SEG40_PAT03                         * Set VRSTR low
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
#FSEL2	DSC 40 			                * delay 1200ns
	LDA #CLOCKREG
*4 
	LPP #SEG100_PAT02 			* Clocks: phiCS low
	LSR #SELCBB
	LSR #DESELECT
* 5 
	DSC 20				        * delay 125ns
	LPP #SEG100_PAT01       	        * Clocks: phiCS high
	LSR #SELCBB
	LSR #DESELECT
* 6
	DSC 20 				        * delay 175ns
	LPP #SEG100_PAT03		        * Clocks: phiC1 low
	LSR #SELCBB
	LSR #DESELECT
* 7
	DSC 20 				        * delay 175ns
	LPP #SEG100_PAT01		        * Clocks: phiC1 high
	LSR #SELCBB
	LSR #DESELECT
	DSC 80 				        * delay 4125ns
* 8
	LRB #COL_LOOP 		                * Start Internal Loop (counter 1)
	LPP #SEG100_PAT04                       * Clocks: phiC2 low
	LSR #SELCBB
	LSR #DESELECT
	DSC 120 			        * delay 6000ns changed from 5000ns
	LSR #SELACQ 		                * trigger CTC on Acq board 
	LSR #DESELECT                           * (by writing to dev addr 0)
	JCB #FSEL3 14		                * IF DIGITAL AVERAGING SET
	JCB #FSEL4 0		                * ELSE CONTINUE WITHOUT DELAY
#FSEL3  LRB #DIGAVG_LOOP                        * DELAY FOR #DA_DELAY us / DIGITAL AVERAGE
	DUS #DA_DELAY
	LPE					* END OF DELAY LOOP
* 9
#FSEL4	DSC 7 			                * delay 625ns
	LPP #SEG100_PAT01		        * Clocks: phiC2 high
	LSR #SELCBB
	LSR #DESELECT                 
	DSC 20 				        * delay 250ns
* 10
	LPP #SEG100_PAT03		        * Clocks: phiC1 low
	LSR #SELCBB
	LSR #DESELECT
	DSC 120 			        * delay 6000ns changed from 5000ns
	LSR #SELACQ 		                * trigger CTC on Acq board
        LSR #DESELECT                           * (by writing to dev addr 0) 
	JCB #FSEL5 14		                * IF DIGITAL AVERAGING SET
	JMP #FSEL6			        * ELSE CONTINUE WITHOUT DELAY
#FSEL5 LRB #DIGAVG_LOOP                         * DELAY FOR #DA_DELAY us / DIGITAL AVERAGE
	DUS #DA_DELAY
	LPE					* END OF DELAY LOOP
* 11
#FSEL6	DSC 9 			                * delay 625ns
	LPP #SEG100_PAT01		        * Clocks: phiC1 high
	LSR #SELCBB
	LSR #DESELECT
	DSC 20 				        * delay 250ns
	LPE 				        * end of internal loop

*Extra Column Clock transition for Orion ref cell
	LPP #SEG100_PAT04 			* CLOCKS : phiC2 LOW
	LSR #SELCBB
	LSR #DESELECT
	DSC 120                                 * changed from DSC 100
        LSR #SELACQ 		                * trigger CTC on Acq board
        LSR #DESELECT                           * (by writing to dev addr 0) 
	JCB #FSEL7 14		                * IF DIGITAL AVERAGING SET
	JMP #FSEL8			        * ELSE CONTINUE WITHOUT DELAY
#FSEL7 LRB #DIGAVG_LOOP                         * DELAY FOR #DA_DELAY us / DIGITAL AVERAGE
	DUS #DA_DELAY
	LPE					* END OF DELAY LOOP
* 11
#FSEL8	DSC 9 			                * delay 625ns
	LPP #SEG100_PAT01 			* CLOCKS: phiC2 HIGH
	LSR #SELCBB
	LSR #DESELECT
	DSC 12
        LPP #SEG100_PAT02                        * CLOCKS: phiCS low
	LSR #SELCBB
	LSR #DESELECT
	DSC 20
	LPP #SEG100_PAT01                        * CLOCKS: phiCS high
	LSR #SELCBB
	LSR #DESELECT
*End extra clock transition

	JCB #FSEL9 15                           * jump if doing row resets 
	LPP #SEG40_PAT01		        * Load end pattern if normal read
                                                * Aladdin: VDDCL high, VGGCL low, VRSTR high
	JMP #FSEL10                              
* 12
#FSEL9	LPP #SEG40_PAT03	                * FBIAS7654: VRSTR low, VRSTG, VDDCL,VGGCL const 
#FSEL10	LDA #FBIAS7654                          * Aladdin: VDDCL high, VGGCL low, VRSTR low 
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
	DSC 2 				        * delay 425ns, 350ns for code execution
* 13
	LDA #FBIAS3210
	LPP #SEG20_PAT01		        * FBIAS3210: VROWON low to high
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
	DSC 8 				        * delay 775ns, 350ns for code execution
* 14
	LDA #FBIAS7654
	LPP #SEG40_PAT01		        * FBIAS4567: Set VRSTR high
	LSR #SELCBB
	LSR #DESELECT
	LSR #SELCBB
	LSR #DESELECT
	DSC 40 				        * delay 850ns, 350 ns for code execution
* 15
	LDA #CLOCKREG
	LPP #SEG100_PAT05 			* Clocks: phiR1, phiROE high
	LSR #SELCBB
	LSR #DESELECT
        
* end of FSEL subroutine
	RET
********************************************************
*ALADDIN SEQUENCE CODE
*Aladdin_READ_END.asm
*
*Toggles PhiSS and PhiFS at end of frame readout
*Comes before INT or RST
*Comes after FSEL
*
*Codes only columns E,F of READ_END (formerly RST/INT) spreadsheet
*
*Assumes Fast Biases and Clocks have been set to
*the proper states by FSEL


#READEND LMR #WRITE32
  	LDA #CLOCKREG
*Set clocks phiRS and phiCS low
  	LPP #SEG120_PAT01 			 * (8010780E)
  	LSR #SELCBB
  	LSR #DESELECT
*Delay 2100 ns, 150 ns for instructions
  	DSC 40
*Set clocks phiRS and phiFS high
  	LPP #SEG120_PAT02 			 * (8030780F)
  	LSR #SELCBB
  	LSR #DESELECT

*  Turn OFF IidleREF (Bias04 @ 0x0104) except during readout 
	LMR #WRITE16
	LPP #IidleOFF
	LSR #SELCBB
        LSR #DESELECT
        LMR #WRITE32
        DMS 2

  	RET
*END READ_END

